@@ -337,17 +337,17 @@ class LambdaToSqsToLambdaProps:
         :summary: The properties for the LambdaToSqsToLambda class.
         '''
         if isinstance(consumer_lambda_function_props, dict):
-            consumer_lambda_function_props = FunctionProps(**consumer_lambda_function_props)
+            consumer_lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**consumer_lambda_function_props)
         if isinstance(dead_letter_queue_props, dict):
-            dead_letter_queue_props = QueueProps(**dead_letter_queue_props)
+            dead_letter_queue_props = aws_cdk.aws_sqs.QueueProps(**dead_letter_queue_props)
         if isinstance(producer_lambda_function_props, dict):
-            producer_lambda_function_props = FunctionProps(**producer_lambda_function_props)
+            producer_lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**producer_lambda_function_props)
         if isinstance(queue_props, dict):
-            queue_props = QueueProps(**queue_props)
+            queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
         if isinstance(sqs_event_source_props, dict):
-            sqs_event_source_props = SqsEventSourceProps(**sqs_event_source_props)
+            sqs_event_source_props = aws_cdk.aws_lambda_event_sources.SqsEventSourceProps(**sqs_event_source_props)
         if isinstance(vpc_props, dict):
-            vpc_props = VpcProps(**vpc_props)
+            vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
         if __debug__:
             type_hints = typing.get_type_hints(LambdaToSqsToLambdaProps.__init__)
             check_type(argname="argument consumer_lambda_function_props", value=consumer_lambda_function_props, expected_type=type_hints["consumer_lambda_function_props"])
